===============================
hiss ( still a work in progress )
===============================


.. image:: https://img.shields.io/pypi/v/hiss.svg
        :target: https://pypi.python.org/pypi/hiss_repl


A simplified, stripped down iPython-based repl with sane defaults and easy dotfiles configuration


* Free software: MIT license
* Documentation: https://hiss.readthedocs.io.
